KemAlgorithm

Enum KemAlgorithm 

#[repr(u16)]
pub enum KemAlgorithm { DhKemP256 = 16, DhKemP384 = 17, DhKemP521 = 18, DhKemK256 = 22, DhKem25519 = 32, DhKem448 = 33, XWingDraft06Obsolete = 77, XWingDraft06 = 25_722, MlKem768 = 65, MlKem1024 = 66, }
KEM Modes

Variants



DhKemP256 = 16

DH KEM on P256



DhKemP384 = 17

DH KEM on P384



DhKemP521 = 18

DH KEM on P521



DhKemK256 = 22

DH KEM on secp256k1



DhKem25519 = 32

DH KEM on x25519



DhKem448 = 33

DH KEM on x448



XWingDraft06Obsolete = 77

👎Deprecated since 0.4.0:

This uses an obsolete code point, use XWingDraft06 instead for the correct code point.

X-WING

This is XWing draft 06, but uses an obsolete code point. You should use XWingDraft06 instead.



XWingDraft06 = 25_722



MlKem768 = 65



MlKem1024 = 66

Implementations

Source

impl KemAlgorithm

pub const fn private_key_len(&self) -> usize

Get the length of the private key for the KEM in bytes.

pub const fn shared_secret_len(&self) -> usize

Get the length of the shared secret for the KEM in bytes.